@@ -1,29 +1,29 @@
-###############################################################################
-# This is a wrapper for Alfred Reibenschuh's PDF::API2
-# Defines methods to create PDF reports
-# By: Andy Orr
-# Date: 06/17/2009
-# Version: 1.33
-###############################################################################
-
 package PDF::Report;
-
-$VERSION = "1.33"; 
-
-=head1 PDF::Report 
+use strict;
 
 =head1 NAME
 
 PDF::Report - A wrapper written for PDF::API2
 
 =head1 SYNOPSIS
-	
+
 	use PDF::Report;
 
-        my $pdf = new PDF::Report(%opts);
+    my $pdf = new PDF::Report(%opts);
+
+=head1 DESCRIPTION
+
+This is a wrapper for Alfred Reibenschuh's PDF::API2
+Defines methods to create PDF reports
+
+=head1 VERSION
+
+ 1.34
 
 =cut
 
+our $VERSION = "1.34";
+
 use strict;
 use PDF::API2;
 
@@ -53,32 +53,32 @@ my @parameterlist=qw(
 );
 ### END GLOBALS ###############################################################
 
-### GLOBAL SUBS ############################################################### 
+### GLOBAL SUBS ###############################################################
 
 =head1 METHODS
 
-=over 4
+=head2 new
 
-=item my $pdf = new PDF::Report(%opts);
+my $pdf = new PDF::Report(%opts);
 
-	Creates a new pdf report object.  
-        If no %opts are specified the module 
+	Creates a new pdf report object.
+        If no %opts are specified the module
         will use the factory defaults.
 
 B<Example:>
 
-	my $pdf = new PDF::Report(PageSize => "letter", 
+	my $pdf = new PDF::Report(PageSize => "letter",
                                   PageOrientation => "Landscape");
 
         my $pdf = new PDF::Report(File => $file);
 
 %opts:
-	
+
         PageSize - '4A', '2A', 'A0', 'A1', 'A2',
-                   'A3', 'A4', 'A5', 'A6', '4B', 
-                   '2B', 'B0', 'B1', 'B2', 'B3', 
-                   'B4', 'B5', 'B6', 'LETTER', 
-                   'BROADSHEET', 'LEDGER', 'TABLOID', 
+                   'A3', 'A4', 'A5', 'A6', '4B',
+                   '2B', 'B0', 'B1', 'B2', 'B3',
+                   'B4', 'B5', 'B6', 'LETTER',
+                   'BROADSHEET', 'LEDGER', 'TABLOID',
                    'LEGAL', 'EXECUTIVE', '36X36'
 
 	PageOrientation - 'Portrait', 'Landscape'
@@ -95,7 +95,7 @@ sub new {
       $DEFAULTS{$dflt} = $defaults{$dflt}; # Overridden from user
     }
   }
-  
+
   my $pageWidth;
   my $pageHeight;
   my $x1;
@@ -157,11 +157,11 @@ sub new {
             };
 
   if (defined $defaults{File} && length($defaults{File})) {
-    $self->{pdf} = PDF::API2->open($defaults{File}) 
+    $self->{pdf} = PDF::API2->open($defaults{File})
                      or die "$defaults{File} not found: $!\n";
   } else {
     $self->{pdf} = PDF::API2->new();
-  } 
+  }
 
   # Default fonts
   $self->{font} = $self->{pdf}->corefont('Helvetica'); # Default font object
@@ -177,7 +177,9 @@ sub new {
   return $self;
 }
 
-=item $pdf->newpage($nopage);
+=head2 newpage
+
+$pdf->newpage($nopage);
 
 Creates a new blank page.  Pass $nopage = 1 to toggle page numbering.
 
@@ -194,12 +196,14 @@ sub newpage {
   # Handle the page numbering if this page is to be numbered
   my $total = $self->pages;
   push(@{$self->{no_page_num}}, $no_page_number);
-    
+
   $self->{page_nbr}++;
   return(0);
 }
 
-=item $pdf->openpage($index);
+=head2 openpage
+
+$pdf->openpage($index);
 
 If no index is specified, this will open the last page of the document.
 
@@ -218,28 +222,43 @@ sub openpage {
   $self->{page} = $self->{pdf}->openpage($index);
 }
 
+=head2 importpage
+
+Import page from another PDF document, see PDF::API2
+
+=cut
+
 sub importpage {
   my $self = shift;
   my $sourcepdf = shift;
   my $sourceindex = shift;
   my $targetindex = shift;  # can be a page object
 
-#  my $source = $self->{pdf}->open($sourcepdf); 
+#  my $source = $self->{pdf}->open($sourcepdf);
 
   $self->{page} = $self->{pdf}->importpage($sourcepdf, $sourceindex,
                                            $targetindex);
 }
 
+=head2 clonepage
+
+Clone page within document, see PDF::API2
+
+=cut
+
+
 sub clonepage {
   my $self = shift;
   my $sourceindex = shift;
   my $targetindex = shift;
 
-  $self->{page} = $self->{pdf}->clonepage($sourceindex, $targetindex); 
+  $self->{page} = $self->{pdf}->clonepage($sourceindex, $targetindex);
 
 }
 
-=item ($pagewidth, $pageheight) = $pdf->getPageDimensions();
+=head2 getPageDimensions
+
+($pagewidth, $pageheight) = $pdf->getPageDimensions();
 
 Returns the width and height of the page according to what page size chosen
 in "new".
@@ -248,13 +267,15 @@ in "new".
 
 sub getPageDimensions {
   my $self = shift;
- 
+
    return($self->{PageWidth}, $self->{PageHeight});
 }
 
-=item $pdf->addRawText($text, $x, $y, $color, $underline, $indent, $rotate);
+=head2 addRawText
 
-Add $text at position $x, $y with $color, $underline, $indent and/or $rotate. 
+$pdf->addRawText($text, $x, $y, $color, $underline, $indent, $rotate);
+
+Add $text at position $x, $y with $color, $underline, $indent and/or $rotate.
 
 =cut
 
@@ -269,7 +290,7 @@ sub addRawText {
   my $txt = $self->{page}->text;
 #  $txt->font($self->{font}, $self->{size});
 #  $txt->transform_rel(-translate => [$x, $y], -rotate => $rotate);
-#  $txt->text($text, -color=>[$color], -underline=>$underline, 
+#  $txt->text($text, -color=>[$color], -underline=>$underline,
 #                          -indent=>$indent);
 
   $txt->textlabel($x, $y, $self->{font}, $self->{size}, $text,
@@ -280,12 +301,12 @@ sub addRawText {
 
 =pod
 
-PDF::API2 Removes all space between every word in the string you pass 
-and then rejoins each word with one space.  If you want to use a string with 
-more than one space between words for formatting purposes, you can either use 
+PDF::API2 Removes all space between every word in the string you pass
+and then rejoins each word with one space.  If you want to use a string with
+more than one space between words for formatting purposes, you can either use
 the hack below or change PDF::API2 (that's what I did ;).  The code below may
-or may not work according to what font you are using.  I used 2 \xA0 per space 
-because that worked for the Helvetica font I was using. 
+or may not work according to what font you are using.  I used 2 \xA0 per space
+because that worked for the Helvetica font I was using.
 
 B<To use a fixed width string with more than one space between words, you can do something like:>
 
@@ -300,14 +321,14 @@ B<To use a fixed width string with more than one space between words, you can do
         } else {
           $new.=$nbsp . $nbsp;
         }
-      } 
+      }
       chop($new);
       return $new;
     }
 
-=cut
+=head2 setAddTextPos
 
-=item $pdf->setAddTextPos($hPos, $vPos);
+$pdf->setAddTextPos($hPos, $vPos);
 
 Set the position on the page.  Used by the addText function.
 
@@ -319,7 +340,9 @@ sub setAddTextPos {
   $self->{vPos}=$vPos;
 }
 
-=item ($hPos, $vPos) = $pdf->getAddTextPos();
+=head2 getAddTextPos
+
+($hPos, $vPos) = $pdf->getAddTextPos();
 
 Return the (x, y) value of the text position.
 
@@ -330,7 +353,9 @@ sub getAddTextPos {
   return($self->{hPos}, $self->{vPos});
 }
 
-=item $pdf->setAlign($align);
+=head2 setAlign
+
+$pdf->setAlign($align);
 
 Set the justification of the text.  Used by the addText function.
 
@@ -346,7 +371,9 @@ sub setAlign {
   }
 }
 
-=item $align = $pdf->getAlign();
+=head2 getAlign
+
+$align = $pdf->getAlign();
 
 Returns the text justification.
 
@@ -357,7 +384,9 @@ sub getAlign {
   return($self->{align});
 }
 
-=item $newtext = $pdf->wrapText($text, $width); 
+=head2 wrapText
+
+$newtext = $pdf->wrapText($text, $width);
 
 This is a helper function called by addText, which can be called by itself.
 wrapText() wraps $text within $width.
@@ -398,12 +427,14 @@ sub wrapText {
   return $newText;
 }
 
-=item $pdf->addText($text, $hPos, $textWidth, $textHeight); 
+=head2 addText
 
-Takes $text and prints it to the current page at $hPos.  You may just want 
-to pass this function $text if the text is "pre-wrapped" and setAddTextPos 
-has been called previously.  Pass a $hPos to change the position the text 
-will be printed on the page.  Pass a  $textWidth and addText will wrap the 
+$pdf->addText($text, $hPos, $textWidth, $textHeight);
+
+Takes $text and prints it to the current page at $hPos.  You may just want
+to pass this function $text if the text is "pre-wrapped" and setAddTextPos
+has been called previously.  Pass a $hPos to change the position the text
+will be printed on the page.  Pass a  $textWidth and addText will wrap the
 text for you.  $textHeight controls the row height.
 
 =cut
@@ -492,9 +523,11 @@ sub addText {
   }
 }
 
-=item $pdf->addParagraph($text, $hPos, $vPos, $width, $height, $indent, $lead);
+=head2 addParagraph
 
-Add $text at ($hPos, $vPos) within $width and $height, with $indent.  
+$pdf->addParagraph($text, $hPos, $vPos, $width, $height, $indent, $lead);
+
+Add $text at ($hPos, $vPos) within $width and $height, with $indent.
 $indent is the number of spaces at the beginning of the first line.
 
 =cut
@@ -505,7 +538,7 @@ sub addParagraph {
   my $txt = $self->{page}->text;
   $txt->font($self->{font}, $self->{size});
 
-#  $txt->paragraph($text, -x => $hPos, -y => $vPos, -w => $width, 
+#  $txt->paragraph($text, -x => $hPos, -y => $vPos, -w => $width,
 #                  -h => $height, -flindent => $indent, -lead => $lead, -rel => 1);
 
 #  0.40.x
@@ -523,26 +556,28 @@ sub addParagragh {
   $self->addParagraph($text, $hPos, $vPos, $width, $height, $indent, $lead);
 }
 
-=item $pdf->centerString($a, $b, $yPos, $text); 
+=head2 centerString
 
-Centers $text between points $a and $b at position $yPos.  Be careful how much 
+$pdf->centerString($a, $b, $yPos, $text);
+
+Centers $text between points $a and $b at position $yPos.  Be careful how much
 text you try to jam between those points, this function shrinks the text till
 it fits!
 
 =cut
 
-sub centerString {  ### CENTERS STRING BETWEEN TWO POINTS
+sub centerString {
   my $self = shift;
   my $PointBegin = shift;
   my $PointEnd = shift;
   my $YPos = shift;
   my $String = shift;
- 
+
   my $OldTextSize = $self->getSize;
   my $TextSize = $OldTextSize;
 
   my $Area = $PointEnd - $PointBegin;
- 
+
   my $StringWidth;
   while (($StringWidth = $self->getStringWidth($String)) > $Area) {
     $self->setSize(--$TextSize);  ### DECREASE THE FONTSIZE TO MAKE IT FIT
@@ -551,7 +586,11 @@ sub centerString {  ### CENTERS STRING BETWEEN TWO POINTS
   my $Offset = ($Area - $StringWidth) / 2;
   $self->addRawText("$String",$PointBegin+$Offset,$YPos);
   $self->setSize($OldTextSize);
-} 
+}
+
+=head2 setRowHeight
+
+=cut
 
 sub setRowHeight {
   my $self = shift;
@@ -560,14 +599,16 @@ sub setRowHeight {
   return (int($size * 1.20));
 }
 
-=item $pdf->getStringWidth($String); 
+=head2 getStringWidth
 
-Returns the width of $String according to the current font and fontsize being 
+$pdf->getStringWidth($String);
+
+Returns the width of $String according to the current font and fontsize being
 used.
 
 =cut
 
-# replaces silly $pdf->{pdf}->calcTextWidth calls    
+# replaces silly $pdf->{pdf}->calcTextWidth calls
 sub getStringWidth {
   my $self = shift;
   my $String = shift;
@@ -577,7 +618,9 @@ sub getStringWidth {
   return $txt->advancewidth($String);
 }
 
-=item $pdf->addImg($file, $x, $y); 
+=head2 addImg
+
+$pdf->addImg($file, $x, $y);
 
 Add image $file to the current page at position ($x, $y).
 
@@ -589,7 +632,9 @@ sub addImg {
   $self->addImgScaled($file, $x, $y, 1);
 }
 
-=item $pdf->addImgScaled($file, $x, $y, $scale); 
+=head2 addImgScaled
+
+$pdf->addImgScaled($file, $x, $y, $scale);
 
 Add image $file to the current page at position ($x, $y) scaled to $scale.
 
@@ -598,14 +643,14 @@ Add image $file to the current page at position ($x, $y) scaled to $scale.
 sub addImgScaled {
   my ( $self, $file, $x, $y, $scale ) = @_;
 
-  my %type = (jpeg => "jpeg", 
+  my %type = (jpeg => "jpeg",
               jpg  => "jpeg",
               tif  => "tiff",
               tiff => "tiff",
               pnm  => "pnm",
               gif  => "gif",
               png  => "png",
-  ); 
+  );
 
   $file =~ /\.(\w+)$/;
   my $ext = $1;
@@ -617,7 +662,9 @@ sub addImgScaled {
   $gfx->image($img, $x, $y, $scale);
 }
 
-=item $pdf->setGfxLineWidth($width);
+=head2 setGfxLineWidth
+
+$pdf->setGfxLineWidth($width);
 
 Set the line width drawn on the page.
 
@@ -629,7 +676,9 @@ sub setGfxLineWidth {
   $self->{linewidth} = $width;
 }
 
-=item $width = $pdf->getGfxLineWidth();
+=head2 getGfxLineWidth
+
+$width = $pdf->getGfxLineWidth();
 
 Returns the current line width.
 
@@ -641,9 +690,11 @@ sub getGfxLineWidth {
   return $self->{linewidth};
 }
 
-=item $pdf->drawLine($x1, $y1, $x2, $y2); 
+=head2 drawLine
 
-Draw a line on the current page starting at ($x1, $y1) and ending 
+$pdf->drawLine($x1, $y1, $x2, $y2);
+
+Draw a line on the current page starting at ($x1, $y1) and ending
 at ($x2, $y2).
 
 =cut
@@ -658,14 +709,16 @@ sub drawLine {
   $gfx->stroke;
 }
 
-=item $pdf->drawRect($x1, $y1, $x2, $y2); 
+=head2 drawRect
+
+$pdf->drawRect($x1, $y1, $x2, $y2);
 
 Draw a rectangle on the current page.  Top left corner is represented by
 ($x1, $y1) and the bottom right corner is ($x2, $y2).
 
 =cut
 
-sub drawRect { 
+sub drawRect {
   my ( $self, $x1, $y1, $x2, $y2 ) = @_;
 
   my $gfx = $self->{page}->gfx;
@@ -674,12 +727,14 @@ sub drawRect {
   $gfx->stroke;
 }
 
-=item $pdf->shadeRect($x1, $y1, $x2, $y2, $color);
+=head2 shadeRect
 
-Shade a rectangle with $color.  Top left corner is ($x1, $y1) and the bottom 
+$pdf->shadeRect($x1, $y1, $x2, $y2, $color);
+
+Shade a rectangle with $color.  Top left corner is ($x1, $y1) and the bottom
 right corner is ($x2, $y2).
 
-=cut
+=over 4
 
 =item B<Defined color-names are:>
 
@@ -727,9 +782,11 @@ and additionally the hsv-hex-notation:
 
         !hsv, !hhssvv, !hhhsssvvv and !hhhhssssvvvv
 
+=back
+
 =cut
 
-sub shadeRect {  
+sub shadeRect {
   my ( $self, $x1, $y1, $x2, $y2, $color ) = @_;
 
   my $gfx = $self->{page}->gfx;
@@ -739,12 +796,14 @@ sub shadeRect {
   $gfx->fill;
 }
 
-=item $pdf->drawPieGraph($x, $y, $size, $rData, $rLabels);
+=head2 drawPieGraph
+
+$pdf->drawPieGraph($x, $y, $size, $rData, $rLabels);
 
 Method to create a piegraph using a reference to an array of values.
-It also takes a reference to an array for labels for each data value.  A 
+It also takes a reference to an array for labels for each data value.  A
 legend with all the colors and labels will appear if $rLabels is passed. $x and
-$y are the coordinates for the center of the pie and $size is the radius.  
+$y are the coordinates for the center of the pie and $size is the radius.
 
 =cut
 
@@ -756,7 +815,7 @@ sub drawPieGraph {
   my $rData = shift;
   my $rLabels = shift;
 
-  my $circ = 360;  
+  my $circ = 360;
   my $a = 0;
   my $b = 0;
   my @colors = &getcolors();
@@ -766,7 +825,7 @@ sub drawPieGraph {
   # Set up the colors we'll use
   my @clr;
   foreach my $elem ( 0 .. $#$rData ) {
-#    push(@clr, $colors[int(rand($#colors))]);  
+#    push(@clr, $colors[int(rand($#colors))]);
      push(@clr, $colors[$elem]);
   }
 
@@ -778,7 +837,7 @@ sub drawPieGraph {
   # Get the percentages
   my @perc;
   foreach my $elem ( 0 .. $#$rData ) {
-    $perc[$elem] = $rData->[$elem] / $total; 
+    $perc[$elem] = $rData->[$elem] / $total;
   }
 
   # Draw a pie
@@ -801,80 +860,88 @@ sub drawPieGraph {
     $self->setSize($fontsize);
     my $colorblocksize = 10;
     my $maxsize = 0;
-    for (0 .. $#$rLabels) { 
-      $maxsize = $self->getStringWidth($rLabels->[$_]) 
-                   if $self->getStringWidth($rLabels->[$_]) > $maxsize; 
+    for (0 .. $#$rLabels) {
+      $maxsize = $self->getStringWidth($rLabels->[$_])
+                   if $self->getStringWidth($rLabels->[$_]) > $maxsize;
     }
     my $top = $y + ((($#perc + 1) * $fontsize) / 2);
     my $left = $x + $size + 8;
     $self->drawRect($left, $top,
-                    $x + $size + 8 + $colorblocksize + $maxsize + 3, 
-                    $y - ((($#perc + 1) * $fontsize) / 2)); 
+                    $x + $size + 8 + $colorblocksize + $maxsize + 3,
+                    $y - ((($#perc + 1) * $fontsize) / 2));
     my $pos = $top - 1;
     $cnt = 0;
     foreach my $nbr (0 .. $#perc) {
-      $self->shadeRect($left+1, $pos, $left+1+$colorblocksize, 
-                       $pos-$colorblocksize, $clr[$cnt++]);    
-      $self->addRawText($rLabels->[$nbr], $left+$colorblocksize+3, 
-                        $pos-$colorblocksize); 
+      $self->shadeRect($left+1, $pos, $left+1+$colorblocksize,
+                       $pos-$colorblocksize, $clr[$cnt++]);
+      $self->addRawText($rLabels->[$nbr], $left+$colorblocksize+3,
+                        $pos-$colorblocksize);
       $pos-=$fontsize;
-    } 
-  } 
+    }
+  }
 }
 
+=head2 getcolors
+
+Returns list of available colours
+
+=cut
+
 sub getcolors {
-  my @cols=qw( 
-        red yellow blue green aqua bisque black  
-        blueviolet brown burlywood cadetblue chartreuse 
-        chocolate coral cornflowerblue cornsilk crimson 
-        cyan darkblue darkcyan darkgoldenrod darkgray 
-        darkgreen darkgrey darkkhaki darkmagenta 
+  my @cols=qw(
+        red yellow blue green aqua bisque black
+        blueviolet brown burlywood cadetblue chartreuse
+        chocolate coral cornflowerblue cornsilk crimson
+        cyan darkblue darkcyan darkgoldenrod darkgray
+        darkgreen darkgrey darkkhaki darkmagenta
         darkolivegreen darkorange darkorchid darkred
         darksalmon darkseagreen darkslateblue darkslategray
-        darkslategrey darkturquoise darkviolet deeppink 
-        deepskyblue dimgrey dodgerblue firebrick 
-        floralwhite forestgreen fuchsia gainsboro ghostwhite 
-        gold goldenrod gray greenyellow 
-        honeydew hotpink indianred indigo ivory khaki 
-        lavender lavenderblush lawngreen lemonchiffon 
-        lightblue lightcoral lightcyan lightgoldenrodyellow 
+        darkslategrey darkturquoise darkviolet deeppink
+        deepskyblue dimgrey dodgerblue firebrick
+        floralwhite forestgreen fuchsia gainsboro ghostwhite
+        gold goldenrod gray greenyellow
+        honeydew hotpink indianred indigo ivory khaki
+        lavender lavenderblush lawngreen lemonchiffon
+        lightblue lightcoral lightcyan lightgoldenrodyellow
         lightgray lightgreen lightgrey lightpink lightsalmon
-        lightseagreen lightskyblue lightslategray 
-        lightslategrey lightsteelblue lightyellow lime 
-        limegreen linen magenta maroon mediumaquamarine 
-        mediumblue mediumorchid mediumpurple mediumseagreen 
-        mediumslateblue mediumspringgreen mediumturquoise 
-        mediumvioletred midnightblue mintcream mistyrose 
-        moccasin navajowhite navy oldlace olivedrab 
-        orange orangered orchid palegoldenrod palegreen 
-        paleturquoise palevioletred papayawhip peachpuff 
-        peru pink plum powderblue purple rosybrown 
-        royalblue saddlebrown salmon sandybrown seagreen 
-        seashell sienna silver skyblue slateblue slategray 
-        slategrey snow springgreen steelblue tan teal 
-        thistle tomato turquoise violet wheat white 
+        lightseagreen lightskyblue lightslategray
+        lightslategrey lightsteelblue lightyellow lime
+        limegreen linen magenta maroon mediumaquamarine
+        mediumblue mediumorchid mediumpurple mediumseagreen
+        mediumslateblue mediumspringgreen mediumturquoise
+        mediumvioletred midnightblue mintcream mistyrose
+        moccasin navajowhite navy oldlace olivedrab
+        orange orangered orchid palegoldenrod palegreen
+        paleturquoise palevioletred papayawhip peachpuff
+        peru pink plum powderblue purple rosybrown
+        royalblue saddlebrown salmon sandybrown seagreen
+        seashell sienna silver skyblue slateblue slategray
+        slategrey snow springgreen steelblue tan teal
+        thistle tomato turquoise violet wheat white
         whitesmoke yellowgreen);
 
   return @cols;
 }
 
-=item $pdf->drawBarcode($x, $y, $scale, $frame, $type, $code, $extn, $umzn, 
+=head2 drawBarcode
+
+$pdf->drawBarcode($x, $y, $scale, $frame, $type, $code, $extn, $umzn,
                         $lmzn, $zone, $quzn, $spcr, $ofwt, $fnsz, $text);
 
-This is really not that complicated, trust me! ;) I am pretty unfamiliar with 
-barcode lingo and types so if I get any of this wrong, lemme know! 
-This is a very flexible way to draw a barcode on your PDF document.  
-$x and $y represent the center of the barcode's position on the document.  
-$scale is the size of the entire barcode 1 being 1:1, which is all you'll 
-need most likely.  $type is the type of barcode which can be codabar, 2of5int, 
-3of9, code128, or ean13.  $code is the alpha-numeric code which the barcode 
-will represent.  $extn is the 
-extension to the $code, where applicable.  $umzn is the upper mending zone and 
-$lmzn is the lower mending zone. $zone is the the zone or height of the bars. 
+This is really not that complicated, trust me! ;) I am pretty unfamiliar with
+barcode lingo and types so if I get any of this wrong, lemme know!
+This is a very flexible way to draw a barcode on your PDF document.
+$x and $y represent the center of the barcode's position on the document.
+$scale is the size of the entire barcode 1 being 1:1, which is all you'll
+need most likely.  $type is the type of barcode which can be codabar, 2of5int,
+3of9, code128, or ean13.  $code is the alpha-numeric code which the barcode
+will represent.  $extn is the
+extension to the $code, where applicable.  $umzn is the upper mending zone and
+$lmzn is the lower mending zone. $zone is the the zone or height of the bars.
 $quzn is the quiet zone or the space between the frame and the barcode.  $spcr
-is what to put between each number/character in the text.  $ofwt is the 
-overflow width.  $fnsz is the fontsize used for the text.  $text is optional 
-text beneathe the barcode. 
+is what to put between each number/character in the text.  $ofwt is the
+overflow width.  $fnsz is the fontsize used for the text.  $text is optional
+text beneathe the barcode.
 
 =cut
 
@@ -893,12 +960,12 @@ sub drawBarcode {
   my $zone = shift; # height of the bars
   my $quzn = shift; # zone between barcode and frame
   my $spcr = shift; # space between numbers
-  my $ofwt = shift; # overflow 
+  my $ofwt = shift; # overflow
   my $fnsz = shift; # fontsize
   my $text = shift; # alt text
 
   my $page = $self->{page};
-  my $gfx  = $page->gfx;  
+  my $gfx  = $page->gfx;
 
   my $bSub = "xo_$type";
   my $bar = $self->{pdf}->$bSub(
@@ -927,7 +994,9 @@ sub drawBarcode {
   $gfx->restore;
 }
 
-=item $pdf->setFont($font);
+=head2 setFont
+
+$pdf->setFont($font);
 
 Creates a new font object of type $font to be used in the page.
 
@@ -947,7 +1016,9 @@ sub setFont {
   $self->{fontname} = $font;
 }
 
-=item $fontname = $pdf->getFont();
+=head2 getFont
+
+$fontname = $pdf->getFont();
 
 Returns the font name currently being used.
 
@@ -959,20 +1030,23 @@ sub getFont {
   return $self->{fontname};
 }
 
-=item $pdf->setSize($size); 
+=head2 setSize
+
+$pdf->setSize($size);
 
 Sets the fontsize to $size.  Called before setFont().
 
 =cut
 
-# sets the font size
 sub setSize {
   my ( $self, $size ) = @_;
 
   $self->{size} = $size;
 }
 
-=item $fontsize = $pdf->getSize();
+=head2 getSize
+
+$fontsize = $pdf->getSize();
 
 Returns the font size currently being used.
 
@@ -984,16 +1058,25 @@ sub getSize {
   return $self->{size};
 }
 
-# the number of pages
+=head2 pages
+
+$pages = $pdf->pages();
+
+The number of pages in the document.
+
+=cut
+
 sub pages {
   my $self = shift;
 
   return $self->{pdf}->pages;
 }
 
-=item $pdf->setInfo(%infohash);
+=head2 setInfo
 
-Sets the info structure of the document.  Valid keys for %infohash: 
+$pdf->setInfo(%infohash);
+
+Sets the info structure of the document.  Valid keys for %infohash:
 Creator, Producer, CreationDate, Title, Subject, Author, etc.
 
 =cut
@@ -1003,9 +1086,10 @@ sub setInfo {
 
   # Over-ride or define %INFO values
   foreach my $key (keys %{$self->{INFO}}) {
-    if (length($info{$key}) and ($info{$key} ne ${$self->{INFO}}{$key})) {
-      ${$self->{INFO}}{$key} = $info{$key};
-    } 
+      next unless (exists($info{$key}) && defined($info{$key}));
+      if (length($info{$key}) and ($info{$key} ne ${$self->{INFO}}{$key})) {
+          ${$self->{INFO}}{$key} = $info{$key};
+      }
   }
   my @orig_keys = keys(%{$self->{INFO}});
   foreach my $key (keys %info) {
@@ -1015,7 +1099,9 @@ sub setInfo {
   }
 }
 
-=item %infohash = $pdf->getInfo();
+=head2 getInfo
+
+%infohash = $pdf->getInfo();
 
 Gets meta-data from the info structure of the document.
 Valid keys for %infohash: Creator, Producer, CreationDate,
@@ -1030,17 +1116,13 @@ sub getInfo {
   return %info;
 }
 
-=item $pdf->saveAs($fileName);
+=head2 saveAs
 
 Saves the document to a file.
 
-=cut
-
-=item B<Example:>
-
-       # Save the document as "file.pdf"
-        my $fileName = "file.pdf";
-       $pdf->saveAs($fileName);
+  # Save the document as "file.pdf"
+  my $fileName = "file.pdf";
+  $pdf->saveAs($fileName);
 
 =cut
 
@@ -1053,14 +1135,10 @@ sub saveAs {
   $self->{pdf}->end();
 }
 
-=item print $pdf->Finish(\&callback());
+=head2 Finish
 
 Returns the PDF document as text.  Pass your own custom routine to do things
-on the footer of the page.  Pass 'roman' for Roman Numeral page numbering. 
-
-=cut
-
-=item B<Example:>
+on the footer of the page.  Pass 'roman' for Roman Numeral page numbering.
 
 	# Hand the document to the web browser
 	print "Content-type: application/pdf\n\n";
@@ -1077,7 +1155,7 @@ sub Finish {
   # Call the callback if one was given to us
   if (ref($callback) eq 'CODE') {
     &$callback($self, $total);
-  # This will print a footer if no $callback is passed for backwards 
+  # This will print a footer if no $callback is passed for backwards
   # compatibility
   } elsif (defined $callback && $callback !~ /none/i) {
     &gen_page_footer($self, $total, $callback);
@@ -1088,13 +1166,20 @@ sub Finish {
 
   return $out;
 }
-### END GLOBAL SUBS ###########################################################
 
-=back
+=head2 getPDFAPI2Object
+
+Object method returns underlying PDF::API2 object
 
 =cut
 
+sub getPDFAPI2Object {
+    my $self = shift;
+    return $self->{pdf};
+}
+
 ### PRIVATE SUBS ##############################################################
+
 sub gen_page_footer {
   my $self = shift;
   my $total = shift;
@@ -1125,10 +1210,71 @@ sub gen_page_footer {
   }
 }
 
-### END PRIVATE SUBS ##########################################################
-
-=head1 AUTHOR
+=head1 AUTHOR EMERITUS
 
 Andrew Orr
 
+=head1 MAINTAINER
+
+Aaron TEEJAY Trevena
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-calendar-model at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PDF-Report>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc PDF::Report
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=PDF-Report>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/PDF-Report>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/PDF-Report>
+
+=item *  METACPAN
+
+L<https://metacpan.org/module/PDF::Report/>
+
+=item * GITHUB
+
+L<https://github.com/hashbangperl/perl-pdf-report>
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item PDF::API2
+
+=back
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2008-2010 Andy Orr
+
+Copyright 2013 Aaron Trevena
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See L<http://dev.perl.org/licenses/> for more information.
+
 =cut
